@@ -14,6 +14,9 @@
 # limitations under the License.
 
 
+# CAM签名/鉴权错误。
+AUTHFAILURE = 'AuthFailure'
+
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
@@ -23,6 +26,9 @@ FAILEDOPERATION_ACCOUNTCOMMON = 'FailedOperation.AccountCommon'
 # 账户未通过认证。
 FAILEDOPERATION_ACCOUNTUSERNOTAUTHENTICATED = 'FailedOperation.AccountUserNotAuthenticated'
 
+# 添加VPC-CNI子网失败
+FAILEDOPERATION_ADDVPCCNISUBNETSFAILED = 'FailedOperation.AddVpcCniSubnetsFailed'
+
 # 伸缩组资源创建报错。
 FAILEDOPERATION_ASCOMMON = 'FailedOperation.AsCommon'
 
@@ -77,6 +83,9 @@ FAILEDOPERATION_CREATECLSTOPIC = 'FailedOperation.CreateClsTopic'
 # cvm创建节点报错。
 FAILEDOPERATION_CVMCOMMON = 'FailedOperation.CvmCommon'
 
+# CVM开启销毁保护，无法移出。
+FAILEDOPERATION_CVMDELETIONPROTECTION = 'FailedOperation.CvmDeletionProtection'
+
 # 存在云服务器在CVM侧查询不到。
 FAILEDOPERATION_CVMNUMBERNOTMATCH = 'FailedOperation.CvmNumberNotMatch'
 
@@ -101,12 +110,27 @@ FAILEDOPERATION_ENABLEVPCCNIFAILED = 'FailedOperation.EnableVPCCNIFailed'
 # 获取CLS采集配置失败。
 FAILEDOPERATION_GETCLSCONFIG = 'FailedOperation.GetClsConfig'
 
+# 获取CLS采集配置绑定的机器组失败。
+FAILEDOPERATION_GETCLSCONFIGMACHINEGROUPS = 'FailedOperation.GetClsConfigMachineGroups'
+
+# 获取CLS索引配置失败。
+FAILEDOPERATION_GETCLSINDEX = 'FailedOperation.GetClsIndex'
+
 # 查询主题集失败。
 FAILEDOPERATION_GETCLSLOGSET = 'FailedOperation.GetClsLogSet'
 
 # 获取CLS机器组失败。
 FAILEDOPERATION_GETCLSMACHINEGROUP = 'FailedOperation.GetClsMachineGroup'
 
+# 获取CLS机器组绑定的采集配置失败。
+FAILEDOPERATION_GETCLSMACHINEGROUPCONFIGS = 'FailedOperation.GetClsMachineGroupConfigs'
+
+# 获取CLS日志主题失败。
+FAILEDOPERATION_GETCLSTOPIC = 'FailedOperation.GetClsTopic'
+
+# Kubernetes client建立失败。
+FAILEDOPERATION_K8SCLIENTBUILDERROR = 'FailedOperation.K8sClientBuildError'
+
 # 通过配置文件创建集群Client错误。
 FAILEDOPERATION_KUBECLIENTCONF = 'FailedOperation.KubeClientConf'
 
@@ -137,6 +161,12 @@ FAILEDOPERATION_KUBERNETESLISTOPERATIONERROR = 'FailedOperation.KubernetesListOp
 # Kubernetes patch 操作失败。
 FAILEDOPERATION_KUBERNETESPATCHOPERATIONERROR = 'FailedOperation.KubernetesPatchOperationError'
 
+# k8s 资源不存在
+FAILEDOPERATION_KUBERNETESRESOURCEEXISTED = 'FailedOperation.KubernetesResourceExisted'
+
+# Kubernetes没有找到。
+FAILEDOPERATION_KUBERNETESRESOURCENOTFOUND = 'FailedOperation.KubernetesResourceNotFound'
+
 # 底层调用CLB未知错误。
 FAILEDOPERATION_LBCOMMON = 'FailedOperation.LbCommon'
 
@@ -146,12 +176,24 @@ FAILEDOPERATION_MARKETGETAUTHFAILED = 'FailedOperation.MarketGetAuthFailed'
 # 操作应用Release失败。
 FAILEDOPERATION_MARKETRELEASEOPERATION = 'FailedOperation.MarketReleaseOperation'
 
+# 修改CLS采集配置失败。
+FAILEDOPERATION_MODIFYCLSCONFIG = 'FailedOperation.ModifyClsConfig'
+
 # 修改CLS索引失败。
 FAILEDOPERATION_MODIFYCLSINDEX = 'FailedOperation.ModifyClsIndex'
 
+# 修改CLS日志主题失败。
+FAILEDOPERATION_MODIFYCLSTOPIC = 'FailedOperation.ModifyClsTopic'
+
 # 网络扩展错误。
 FAILEDOPERATION_NETWORKSCALEERROR = 'FailedOperation.NetworkScaleError'
 
+# 节点存在辅助网卡
+FAILEDOPERATION_NODEEXISTSSECONDARYNETWORKINTERFACE = 'FailedOperation.NodeExistsSecondaryNetworkInterface'
+
+# 节点池查询失败
+FAILEDOPERATION_NODEPOOLQUERYFAILED = 'FailedOperation.NodePoolQueryFailed'
+
 # 镜像OS不支持。
 FAILEDOPERATION_OSNOTSUPPORT = 'FailedOperation.OsNotSupport'
 
@@ -176,12 +218,18 @@ FAILEDOPERATION_RBACFORBIDDEN = 'FailedOperation.RBACForbidden'
 # 记录没有发现。
 FAILEDOPERATION_RECORDNOTFOUND = 'FailedOperation.RecordNotFound'
 
+# tag错误
+FAILEDOPERATION_TAGCOMMON = 'FailedOperation.TagCommon'
+
 # 已有相同任务执行中。
 FAILEDOPERATION_TASKALREADYRUNNING = 'FailedOperation.TaskAlreadyRunning'
 
 # 任务当前所处状态不支持此操作。
 FAILEDOPERATION_TASKLIFESTATEERROR = 'FailedOperation.TaskLifeStateError'
 
+# 任务未找到。
+FAILEDOPERATION_TASKNOTFOUND = 'FailedOperation.TaskNotFound'
+
 # 询价错误。
 FAILEDOPERATION_TRADECOMMON = 'FailedOperation.TradeCommon'
 
@@ -299,6 +347,9 @@ INTERNALERROR_IMAGEIDNOTFOUND = 'InternalError.ImageIdNotFound'
 # 初始化master失败。
 INTERNALERROR_INITMASTERFAILED = 'InternalError.InitMasterFailed'
 
+# 余额不足。
+INTERNALERROR_INSUFFICIENTBALANCE = 'InternalError.InsufficientBalance'
+
 # 无效CIDR。
 INTERNALERROR_INVALIDPRIVATENETWORKCIDR = 'InternalError.InvalidPrivateNetworkCidr'
 
@@ -344,6 +395,12 @@ INTERNALERROR_MARKETINTERNALSERVERERROR = 'InternalError.MarketInternalServerErr
 # 操作应用Release失败。
 INTERNALERROR_MARKETRELEASEOPERATION = 'InternalError.MarketReleaseOperation'
 
+# 无支付权限。
+INTERNALERROR_NOPAYMENTACCESS = 'InternalError.NoPaymentAccess'
+
+# 未实名认证。
+INTERNALERROR_NOTVERIFIED = 'InternalError.NotVerified'
+
 # 镜像OS不支持。
 INTERNALERROR_OSNOTSUPPORT = 'InternalError.OsNotSupport'
 
@@ -389,7 +446,7 @@ INTERNALERROR_TASKLIFESTATEERROR = 'InternalError.TaskLifeStateError'
 # 任务未找到。
 INTERNALERROR_TASKNOTFOUND = 'InternalError.TaskNotFound'
 
-# 询价错误。
+# 计费错误。
 INTERNALERROR_TRADECOMMON = 'InternalError.TradeCommon'
 
 # 账户余额不足。
@@ -482,6 +539,15 @@ INVALIDPARAMETER_SUBNETINVALIDERROR = 'InvalidParameter.SubnetInvalidError'
 # 子网不存在。
 INVALIDPARAMETER_SUBNETNOTEXIST = 'InvalidParameter.SubnetNotExist'
 
+# 客户创建参数中，k8s 版本、运行时版本或 tke-eni-agent 版本不支持客户选择的操作系统中的CgroupV2。
+INVALIDPARAMETER_VERSIONNOTSUPPORTCGROUPV2 = 'InvalidParameter.VersionNotSupportCgroupV2'
+
+# 超出配额
+INVALIDPARAMETERVALUE_LIMITEXCEEDED = 'InvalidParameterValue.LimitExceeded'
+
+# 参数值中数量错误。
+INVALIDPARAMETERVALUE_SIZE = 'InvalidParameterValue.Size'
+
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
@@ -506,6 +572,9 @@ RESOURCEINUSE_RESOURCEEXISTALREADY = 'ResourceInUse.ResourceExistAlready'
 # 所选子网已存在。
 RESOURCEINUSE_SUBNETALREADYEXIST = 'ResourceInUse.SubnetAlreadyExist'
 
+# 获取 tke apiserver 失败
+RESOURCEINUSE_TKEAPISERVERGETERROR = 'ResourceInUse.TKEAPIServerGetError'
+
 # 资源不足。
 RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 
@@ -527,6 +596,12 @@ RESOURCENOTFOUND_KUBERESOURCENOTFOUND = 'ResourceNotFound.KubeResourceNotFound'
 # 未找到该kubernetes资源。
 RESOURCENOTFOUND_KUBERNETESRESOURCENOTFOUND = 'ResourceNotFound.KubernetesResourceNotFound'
 
+# CLS日志主题不存在。
+RESOURCENOTFOUND_LOGCOLLECTORCLSLOGTOPICNOTEXISTS = 'ResourceNotFound.LogCollectorClsLogTopicNotExists'
+
+# 资源未找到。
+RESOURCENOTFOUND_NOTFOUND = 'ResourceNotFound.NotFound'
+
 # 找不到对应路由表。
 RESOURCENOTFOUND_ROUTETABLENOTFOUND = 'ResourceNotFound.RouteTableNotFound'
 
@@ -554,6 +629,9 @@ UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 # 无该接口CAM权限。
 UNAUTHORIZEDOPERATION_CAMNOAUTH = 'UnauthorizedOperation.CamNoAuth'
 
+# 没有RBAC权限
+UNAUTHORIZEDOPERATION_NORBACPERMISSIONS = 'UnauthorizedOperation.NoRBACPermissions'
+
 # 未知参数错误。
 UNKNOWNPARAMETER = 'UnknownParameter'
 
